{
	"name" : "Sales Management - Reporting",
	"version" : "1.0",
	"author" : "Tiny",
	"website" : "http://tinyerp.com/module_project.html",
	"depends" : ["project"],
	"category" : "Generic Modules/Sales & Purchases",
	"description": "A module that adds some reports on the sales",
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["report_project_view.xml"],
	"active": False,
	"installable": True
}
